# Onboarding Guide

We have created a simple onboarding guide to help you get started with Aviary.
This guide goes through Levels 1, 2, and 3 in order, then discusses adding external subsystems to Aviary problems.
This guide is meant to be a quick introduction to Aviary and is not meant to be a comprehensive guide to all of Aviary's features.
Instead, view it as a way to get some more detail and info on portions of Aviary.

If you have a specific use case for Aviary already and just need to know how to use Aviary to solve your problem, please jump to the User Guide or just search for your desired topic.

```{note}
These onboarding doc pages were purposefully written by somebody who was new to Aviary.
We hope this addresses some of the first-time questions you may have.
```